summaryrefslogtreecommitdiffstats
path: root/container-core
diff options
context:
space:
mode:
authorJon Bratseth <bratseth@oath.com>2018-11-02 12:56:29 +0100
committergjoranv <gv@oath.com>2019-01-21 15:09:26 +0100
commit2783f793601d1db466c0eebb65691651c9bc4620 (patch)
tree886f3b7391a57c0e5d0bfab3873d77b4d3f9da59 /container-core
parent79958912db472d9e28338ba0eb1d482ef00a3578 (diff)
Make OpenNlpLinguistics default
Diffstat (limited to 'container-core')
-rw-r--r--container-core/src/main/java/com/yahoo/language/provider/DefaultLinguisticsProvider.java (renamed from container-core/src/main/java/com/yahoo/language/provider/SimpleLinguisticsProvider.java)9
1 files changed, 4 insertions, 5 deletions
diff --git a/container-core/src/main/java/com/yahoo/language/provider/SimpleLinguisticsProvider.java b/container-core/src/main/java/com/yahoo/language/provider/DefaultLinguisticsProvider.java
index 5d4b7087e0e..20d58a36aff 100644
--- a/container-core/src/main/java/com/yahoo/language/provider/SimpleLinguisticsProvider.java
+++ b/container-core/src/main/java/com/yahoo/language/provider/DefaultLinguisticsProvider.java
@@ -2,25 +2,24 @@
package com.yahoo.language.provider;
import com.google.inject.Inject;
+import com.yahoo.language.opennlp.OpenNlpLinguistics;
import com.yahoo.language.simple.SimpleLinguistics;
import com.yahoo.container.di.componentgraph.Provider;
import com.yahoo.language.Linguistics;
/**
* Provides simple linguistics if no linguistics component has been explicitly configured
* (dependency injection will fallback to providers if no components of the requested type is found).
*
* @author bratseth
*/
-public class SimpleLinguisticsProvider implements Provider<Linguistics> {
+public class DefaultLinguisticsProvider implements Provider<Linguistics> {
private final Linguistics linguistics;
@SuppressWarnings("deprecation")
@Inject
- public SimpleLinguisticsProvider() {
- linguistics = new SimpleLinguistics();
- }
+ public DefaultLinguisticsProvider() { linguistics = new OpenNlpLinguistics(); }
@Override
public Linguistics get() { return linguistics; }
@@ -2,25 +2,24 @@
import com.yahoo.language.Linguistics;
/**
- * Provides simple linguistics if no linguistics component has been explicitly configured
+ * Provides the default linguistics implementation if no linguistics component has been explicitly configured
* (dependency injection will fallback to providers if no components of the requested type is found).
*